@@ -1,5 +1,9 @@
+# Copyright (c) 2023-2025 Progress Software Corporation and/or its subsidiaries or affiliates. All Rights Reserved.
+
+
 import json
 from collections import OrderedDict
+from email.message import Message
 from typing import Union
 
 from marklogic.transactions import Transaction
@@ -263,22 +267,24 @@ def _extract_values_from_header(part) -> dict:
     """
     encoding = part.encoding
     disposition = part.headers["Content-Disposition".encode(encoding)].decode(encoding)
-    disposition_values = {}
-    for item in disposition.split(";"):
-        tokens = item.split("=")
-        # The first item will be "attachment" and can be ignored.
-        if len(tokens) == 2:
-            disposition_values[tokens[0].strip()] = tokens[1]
 
     content_type = None
     if part.headers.get("Content-Type".encode(encoding)):
         content_type = part.headers["Content-Type".encode(encoding)].decode(encoding)
 
-    uri = disposition_values["filename"]
-    if uri.startswith('"'):
-        uri = uri[1:]
-    if uri.endswith('"'):
-        uri = uri[:-1]
+    content_disposition_header = part.headers[
+        "Content-Disposition".encode(encoding)
+    ].decode(encoding)
+    msg = Message()
+    msg["content-disposition"] = content_disposition_header
+    uri = msg.get_filename()
+
+    disposition_values = {}
+    for item in disposition.replace(uri, "").split(";"):
+        tokens = item.split("=")
+        key = tokens[0].strip()
+        if key in ["category", "versionId"]:
+            disposition_values[key] = tokens[1]
 
     return {
         "uri": uri,
